pytilities.geometry.verboserectangle.VerboseRectangle

Package pytilities :: Package geometry :: Module verboserectangle :: Class VerboseRectangle |
[hide private]
[frames] | no frames]

# Class VerboseRectangle

source code

                                         object --+
                                                  |
    attributecollectionbase.AttributeCollectionBase --+
                                                      |
                                                     VerboseRectangle

A Rectangle wrapper that sends out events

It supports all attributes of Rectangle. For Rectangle specific documentation, see Rectangle.

Events:

> size_changed

>   Parameters:

>   > `old_size` :: Vector
>   >   the old size

Instance Methods | [hide private]
__init__(self, *args, **kwargs) Construct a VerboseRectangle. | source code
inflate(self, *args) | source code
Inherited from `attributecollectionbase.AttributeCollectionBase`: `__abs__`, `__add__`, `__copy__`, `__delattr__`, `__div__`, `__eq__`, `__floordiv__`, `__getattr__`, `__getitem__`, `__iadd__`, `__imul__`, `__iter__`, `__len__`, `__mul__`, `__neg__`, `__neq__`, `__nonzero__`, `__pos__`, `__rdiv__`, `__rfloordiv__`, `__rmul__`, `__rtruediv__`, `__setattr__`, `__setitem__`, `__str__`, `__sub__`, `__truediv__` Inherited from `attributecollectionbase.AttributeCollectionBase` (private): `_append_attribute_collection` Inherited from `object`: `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
| bounds
| width
| height
| size
| left
| top
| right
| bottom
| top_left
| top_right
| bottom_left
| bottom_right
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
Construct a VerboseRectangle. Parameters: r :: Rectangle the rectangle to wrap Overrides: object.__init__

Property Details | [hide private]

### bounds Get Method: unreachable.bounds(self) Set Method: unreachable.bounds(self, args)

### width Get Method: unreachable.width(self) Set Method: unreachable.width(self, value)

### height Get Method: unreachable.height(self) Set Method: unreachable.height(self, value)

### size Get Method: unreachable.size(self) Set Method: unreachable.size(self, value)

### left Get Method: unreachable.left(self) Set Method: unreachable.left(self, value)

### top Get Method: unreachable.top(self) Set Method: unreachable.top(self, value)

### right Get Method: unreachable.right(self) Set Method: unreachable.right(self, value)

### bottom Get Method: unreachable.bottom(self) Set Method: unreachable.bottom(self, value)

### top_left Get Method: unreachable.top_left(self) Set Method: unreachable.top_left(self, value)

### top_right Get Method: unreachable.top_right(self) Set Method: unreachable.top_right(self, value)

### bottom_left Get Method: unreachable.bottom_left(self) Set Method: unreachable.bottom_left(self, value)

### bottom_right Get Method: unreachable.bottom_right(self) Set Method: unreachable.bottom_right(self, value)